0.0.6
-----

* Proper handling of /DescendantFonts when creating letterhead XObject.

0.0.5
-----

* Template bug fix related to compression.

0.0.4
-----

* Added page-break-before CSS property.

0.0.3
-----

* Added missing dependencies.

0.0.2
-----

* Bug fixes and improvements.

0.0.1
-----

* Initial release.
